import { __decorate } from 'tslib';
import { Prop, Model, Component, Vue } from 'vue-property-decorator';
import { CoolSelect, CoolSelectPlugin } from 'vue-cool-select';
import { namespace } from 'vuex-class';
import VueToast from 'vue-toast-notification';
import VueTimePicker from 'vue2-timepicker';

const secureToken = namespace('SecureToken');
/**
 * Class-component
 */
let AssociatePicker = class AssociatePicker extends Vue {
    constructor() {
        super(...arguments);
        this.items = [];
        this.selected = null;
        this.loading = false;
        this.timeoutId = null;
        this.noData = false;
        this.hostName = window.location.hostname;
    }
    async onSearch(search) {
        const lettersLimit = 2;
        this.noData = false;
        if (search.length < lettersLimit) {
            this.items = [];
            this.loading = false;
            return;
        }
        this.loading = true;
        clearTimeout(this.timeoutId);
        this.timeoutId = setTimeout(async () => {
            const client = await this.sharepointContext.msGraphClientFactory.getClient();
            // https://stackoverflow.com/a/58647582/823927 - We just have to get back a ton of extra fields
            const response = await client
                .api(`/me/people/?$search="${search}"`)
                .version('v1.0')
                .get();
            this.items = response.value.filter((person) => person.userPrincipalName);
            this.loading = false;
            if (!this.items.length) {
                this.noData = true;
            }
        }, 500);
    }
};
__decorate([
    secureToken.Getter
], AssociatePicker.prototype, "sharepointContext", void 0);
__decorate([
    Prop()
], AssociatePicker.prototype, "pickerId", void 0);
__decorate([
    Model('input')
], AssociatePicker.prototype, "value", void 0);
AssociatePicker = __decorate([
    Component({
        components: { CoolSelect },
    })
], AssociatePicker);
var script = AssociatePicker;

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

const isOldIE = typeof navigator !== 'undefined' &&
    /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
function createInjector(context) {
    return (id, style) => addStyle(id, style);
}
let HEAD;
const styles = {};
function addStyle(id, css) {
    const group = isOldIE ? css.media || 'default' : id;
    const style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
    if (!style.ids.has(id)) {
        style.ids.add(id);
        let code = css.source;
        if (css.map) {
            // https://developer.chrome.com/devtools/docs/javascript-debugging
            // this makes source maps inside style tags work properly in Chrome
            code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
            // http://stackoverflow.com/a/26603875
            code +=
                '\n/*# sourceMappingURL=data:application/json;base64,' +
                    btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                    ' */';
        }
        if (!style.element) {
            style.element = document.createElement('style');
            style.element.type = 'text/css';
            if (css.media)
                style.element.setAttribute('media', css.media);
            if (HEAD === undefined) {
                HEAD = document.head || document.getElementsByTagName('head')[0];
            }
            HEAD.appendChild(style.element);
        }
        if ('styleSheet' in style.element) {
            style.styles.push(code);
            style.element.styleSheet.cssText = style.styles
                .filter(Boolean)
                .join('\n');
        }
        else {
            const index = style.ids.size - 1;
            const textNode = document.createTextNode(code);
            const nodes = style.element.childNodes;
            if (nodes[index])
                style.element.removeChild(nodes[index]);
            if (nodes.length)
                style.element.insertBefore(textNode, nodes[index]);
            else
                style.element.appendChild(textNode);
        }
    }
}

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("cool-select", {
    ref: _vm.pickerId,
    attrs: {
      value: _vm.value,
      id: _vm.pickerId,
      items: _vm.items,
      loading: _vm.loading,
      "item-text": "displayName",
      placeholder: "Enter associate name",
      "disable-filtering-by-search": "",
      "menu-default-position": "bottom",
      "menu-dynamic-position": "false"
    },
    on: {
      input: function($event) {
        return _vm.$emit("input", $event)
      },
      search: function($event) {
        return _vm.onSearch($event)
      }
    },
    scopedSlots: _vm._u([
      {
        key: "no-data",
        fn: function() {
          return [
            _vm._v(
              "\n        " +
                _vm._s(
                  _vm.noData
                    ? "No associates found."
                    : "Enter at least 2 letters to search."
                ) +
                "\n    "
            )
          ]
        },
        proxy: true
      },
      {
        key: "item",
        fn: function(ref) {
          var item = ref.item;
          return [
            _c("div", { staticClass: "associate" }, [
              _c("img", {
                staticClass: "profileImage",
                attrs: {
                  src:
                    "https://" +
                    _vm.hostName +
                    "/_layouts/15/userphoto.aspx?size=S&accountname=" +
                    item.userPrincipalName
                }
              }),
              _vm._v(" "),
              _c("div", [
                _c("span", [_vm._v(_vm._s(item.displayName))]),
                _vm._v(" "),
                _c("br"),
                _vm._v(" "),
                _c("span", { staticClass: "jobTitle" }, [
                  _vm._v(_vm._s(item.jobTitle))
                ])
              ])
            ])
          ]
        }
      }
    ])
  })
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  const __vue_inject_styles__ = function (inject) {
    if (!inject) return
    inject("data-v-c75f8df6_0", { source: ".IZ-select * {\n  box-sizing: border-box;\n}\n.IZ-select__input-wrap {\n  display: flex;\n  align-items: center;\n  height: 100%;\n}\n.IZ-select__input,\n.IZ-select__input input {\n  height: 100%;\n}\n.fade-leave-active {\n  position: absolute;\n}\n.fade-enter-active,\n.fade-leave,\n.fade-leave-to {\n  transition: opacity 0.2s;\n}\n.fade-enter,\n.fade-leave-to {\n  opacity: 0;\n}\n.IZ-select {\n  position: relative;\n  outline: none;\n}\n.IZ-select .IZ-select__input {\n  font-weight: 400;\n  font-size: 1rem;\n  line-height: 1.5;\n}\n.IZ-select .IZ-select__input input {\n  height: calc(1.5em + 0.75rem);\n  padding: 0.375rem 0.75rem;\n}\n.IZ-select--sm .IZ-select__input {\n  border-radius: 0.2rem;\n}\n.IZ-select--sm .IZ-select__input input {\n  height: calc(1.5em + 0.5rem);\n  padding: 0.25rem 0.5rem;\n  font-size: 0.875rem;\n  line-height: 1.5;\n}\n.IZ-select--lg .IZ-select__input {\n  border-radius: 0.3rem;\n}\n.IZ-select--lg .IZ-select__input input {\n  height: calc(1.5em + 1rem);\n  padding: 0.5rem 1rem;\n  font-size: 1.25rem;\n  line-height: 1.5;\n}\n.IZ-select__input {\n  align-items: center;\n  display: flex;\n  flex: 1 1 auto;\n  flex-wrap: wrap;\n  width: 100%;\n  color: #495057;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid #ced4da;\n  border-radius: 0.25rem;\n  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n.IZ-select__input.IZ-select__input--selection-slot {\n  padding-left: 0.75rem;\n}\n.IZ-select__input.IZ-select__input--selection-slot input {\n  padding-left: 10px;\n}\n.IZ-select__input.IZ-select__input--has-error {\n  border: 1px solid #dc3545 !important;\n  caret-color: #ff5252 !important;\n}\n.IZ-select__input.IZ-select__input--has-error input {\n  color: #ff5252 !important;\n}\n.IZ-select__input.IZ-select__input--successful {\n  border: 1px solid #28a745 !important;\n  caret-color: #28c346 !important;\n}\n.IZ-select__input.IZ-select__input--focused {\n  border-color: #80bdff;\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(128, 189, 255, 0.5);\n}\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--has-error {\n  box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25) !important;\n}\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--successful {\n  box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25) !important;\n}\n.IZ-select__input.IZ-select__input--disabled {\n  pointer-events: none;\n  background-color: #e9ecef;\n  opacity: 1;\n}\n.IZ-select__input.IZ-select__input--disabled input {\n  color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::-webkit-input-placeholder {\n  color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::-moz-placeholder {\n  color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled:-ms-input-placeholder {\n  color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::-ms-input-placeholder {\n  color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::placeholder {\n  color: #6c737a !important;\n}\n.IZ-select__input input {\n  font-size: 1rem;\n  background-size: 25px 25px;\n  background-position: right 10px center;\n  background-repeat: no-repeat;\n  color: #495057 !important;\n  background-color: transparent;\n  border-style: none;\n  pointer-events: auto;\n  flex: 1 1;\n  margin-top: 0;\n  min-width: 0;\n  position: relative;\n  line-height: 20px;\n  max-width: 100%;\n  width: 100%;\n}\n.IZ-select__input input:focus {\n  outline: none;\n}\n.IZ-select__input input:disabled {\n  pointer-events: none;\n}\n.IZ-select__menu {\n  opacity: 0;\n  transition: opacity 0.1s;\n  position: absolute;\n  z-index: 8;\n  transform-origin: left top 0;\n  background-color: #fff;\n  border: 1px solid #ced4da;\n  border-radius: 0.25rem;\n  box-shadow: 0 2px 11px -2px rgba(0, 0, 0, 0.19);\n}\n.IZ-select__menu--at-top {\n  border-bottom: 0;\n  border-bottom-left-radius: 0;\n  border-bottom-right-radius: 0;\n}\n.IZ-select__menu--at-top.IZ-select__menu--disable-search {\n  border-bottom: 1px;\n  border-bottom-left-radius: 0.25rem;\n  border-bottom-right-radius: 0.25rem;\n}\n.IZ-select__menu--at-bottom {\n  border-top: 0;\n  border-top-left-radius: 0;\n  border-top-right-radius: 0;\n}\n.IZ-select__menu--at-bottom.IZ-select__menu--disable-search {\n  border-top: 1px;\n  border-top-left-radius: 0.25rem;\n  border-top-right-radius: 0.25rem;\n}\n.IZ-select__menu .IZ-select__menu-items {\n  overflow-y: auto;\n  overflow-x: hidden;\n}\n.IZ-select__menu .IZ-select__no-data {\n  margin: 0 10px;\n}\n.IZ-select__item {\n  cursor: pointer;\n  padding: 10px 14px;\n  transition: 0.3s cubic-bezier(0.25, 0.8, 0.5, 1);\n}\n.IZ-select__item:hover {\n  background-color: #f2f2f2;\n}\n.IZ-select__item.IZ-select__item--selected {\n  color: #1976d2 !important;\n}\n.IZ-select__error {\n  margin-top: 0.55rem;\n  font-size: 85%;\n  color: #dc3545;\n}\n.associate {\n  display: flex;\n  align-items: center;\n}\n.jobTitle {\n  color: grey;\n}\n.profileImage {\n  max-width: 60px;\n  margin-right: 10px;\n  border: 1px solid #eaecf0;\n}\n.loading-indicator {\n  width: 20px;\n  margin-right: 10px;\n}\n\n/*# sourceMappingURL=AssociatePicker.vue.map */", map: {"version":3,"sources":["C:\\Users\\astanley\\local web\\npm packages\\vue-ui-components\\src\\components\\AssociatePicker.vue","AssociatePicker.vue"],"names":[],"mappings":"AAoGA;EACA,sBAAA;ACnGA;ADqGA;EACA,aAAA;EACA,mBAAA;EACA,YAAA;AClGA;ADoGA;;EAEA,YAAA;ACjGA;ADmGA;EACA,kBAAA;AChGA;ADkGA;;;EAGA,wBAAA;AC/FA;ADiGA;;EAEA,UAAA;AC9FA;ADgGA;EACA,kBAAA;EACA,aAAA;AC7FA;AD+FA;EACA,gBAAA;EACA,eAAA;EACA,gBAAA;AC5FA;AD8FA;EACA,6BAAA;EACA,yBAAA;AC3FA;AD6FA;EACA,qBAAA;AC1FA;AD4FA;EACA,4BAAA;EACA,uBAAA;EACA,mBAAA;EACA,gBAAA;ACzFA;AD2FA;EACA,qBAAA;ACxFA;AD0FA;EACA,0BAAA;EACA,oBAAA;EACA,kBAAA;EACA,gBAAA;ACvFA;ADyFA;EACA,mBAAA;EACA,aAAA;EACA,cAAA;EACA,eAAA;EACA,WAAA;EACA,cAAA;EACA,sBAAA;EACA,4BAAA;EACA,yBAAA;EACA,sBAAA;EACA,4GAAA;ACtFA;ADwFA;EACA,qBAAA;ACrFA;ADuFA;EACA,kBAAA;ACpFA;ADsFA;EACA,oCAAA;EACA,+BAAA;ACnFA;ADqFA;EACA,yBAAA;AClFA;ADoFA;EACA,oCAAA;EACA,+BAAA;ACjFA;ADmFA;EACA,qBAAA;EACA,UAAA;EACA,iDAAA;AChFA;ADkFA;EACA,2DAAA;AC/EA;ADiFA;EACA,2DAAA;AC9EA;ADgFA;EACA,oBAAA;EACA,yBAAA;EACA,UAAA;AC7EA;AD+EA;EACA,yBAAA;AC5EA;AD8EA;EACA,yBAAA;AC3EA;AD6EA;EACA,yBAAA;AC1EA;AD4EA;EACA,yBAAA;ACzEA;AD2EA;EACA,yBAAA;ACxEA;AD0EA;EACA,yBAAA;ACvEA;ADyEA;EACA,eAAA;EACA,0BAAA;EACA,sCAAA;EACA,4BAAA;EACA,yBAAA;EACA,6BAAA;EACA,kBAAA;EACA,oBAAA;EACA,SAAA;EACA,aAAA;EACA,YAAA;EACA,kBAAA;EACA,iBAAA;EACA,eAAA;EACA,WAAA;ACtEA;ADwEA;EACA,aAAA;ACrEA;ADuEA;EACA,oBAAA;ACpEA;ADsEA;EACA,UAAA;EACA,wBAAA;EACA,kBAAA;EACA,UAAA;EACA,4BAAA;EACA,sBAAA;EACA,yBAAA;EACA,sBAAA;EACA,+CAAA;ACnEA;ADqEA;EACA,gBAAA;EACA,4BAAA;EACA,6BAAA;AClEA;ADoEA;EACA,kBAAA;EACA,kCAAA;EACA,mCAAA;ACjEA;ADmEA;EACA,aAAA;EACA,yBAAA;EACA,0BAAA;AChEA;ADkEA;EACA,eAAA;EACA,+BAAA;EACA,gCAAA;AC/DA;ADiEA;EACA,gBAAA;EACA,kBAAA;AC9DA;ADgEA;EACA,cAAA;AC7DA;AD+DA;EACA,eAAA;EACA,kBAAA;EACA,gDAAA;AC5DA;AD8DA;EACA,yBAAA;AC3DA;AD6DA;EACA,yBAAA;AC1DA;AD4DA;EACA,mBAAA;EACA,cAAA;EACA,cAAA;ACzDA;AD2DA;EACA,aAAA;EACA,mBAAA;ACxDA;AD0DA;EACA,WAAA;ACvDA;ADyDA;EACA,eAAA;EACA,kBAAA;EACA,yBAAA;ACtDA;ADwDA;EACA,WAAA;EACA,kBAAA;ACrDA;;AAEA,8CAA8C","file":"AssociatePicker.vue","sourcesContent":["<template>\r\n    <cool-select\r\n        :value=\"value\"\r\n        @input=\"$emit('input', $event)\"\r\n        :id=\"pickerId\"\r\n        :ref=\"pickerId\"\r\n        :items=\"items\"\r\n        :loading=\"loading\"\r\n        item-text=\"displayName\"\r\n        placeholder=\"Enter associate name\"\r\n        disable-filtering-by-search\r\n        menu-default-position=\"bottom\"\r\n        menu-dynamic-position=\"false\"\r\n        @search=\"onSearch($event)\"\r\n    >\r\n        <template #no-data>\r\n            {{ noData ? 'No associates found.' : 'Enter at least 2 letters to search.' }}\r\n        </template>\r\n        <template #item=\"{ item }\">\r\n            <div class=\"associate\">\r\n                <img\r\n                    :src=\"`https://${hostName}/_layouts/15/userphoto.aspx?size=S&accountname=${item.userPrincipalName}`\"\r\n                    class=\"profileImage\"\r\n                />\r\n\r\n                <div>\r\n                    <span>{{ item.displayName }}</span>\r\n                    <br />\r\n                    <span class=\"jobTitle\">{{ item.jobTitle }}</span>\r\n                </div>\r\n            </div>\r\n        </template>\r\n    </cool-select>\r\n</template>\r\n\r\n<script lang=\"ts\">\r\nimport { Vue, Component, Prop, Model } from 'vue-property-decorator';\r\n\r\nimport { CoolSelect } from 'vue-cool-select';\r\nimport { MSGraphClient } from '@microsoft/sp-http';\r\n\r\nimport { namespace } from 'vuex-class';\r\nconst secureToken = namespace('SecureToken');\r\n\r\n/**\r\n * Class-component\r\n */\r\n\r\n@Component({\r\n    components: { CoolSelect },\r\n})\r\nexport default class AssociatePicker extends Vue {\r\n    @secureToken.Getter\r\n    public sharepointContext;\r\n\r\n    items = [];\r\n    selected = null;\r\n    loading = false;\r\n    timeoutId: any = null;\r\n    noData = false;\r\n    hostName = window.location.hostname;\r\n\r\n    // https://v3.vuejs.org/guide/component-template-refs.html\r\n    @Prop()\r\n    public pickerId;\r\n\r\n    @Model('input')\r\n    public value;\r\n\r\n    public async onSearch(search) {\r\n        const lettersLimit = 2;\r\n\r\n        this.noData = false;\r\n        if (search.length < lettersLimit) {\r\n            this.items = [];\r\n            this.loading = false;\r\n            return;\r\n        }\r\n        this.loading = true;\r\n\r\n        clearTimeout(this.timeoutId);\r\n        this.timeoutId = setTimeout(async () => {\r\n            const client: MSGraphClient = await this.sharepointContext.msGraphClientFactory.getClient();\r\n            // https://stackoverflow.com/a/58647582/823927 - We just have to get back a ton of extra fields\r\n            const response = await client\r\n                .api(`/me/people/?$search=\"${search}\"`)\r\n                .version('v1.0')\r\n                .get();\r\n            this.items = response.value.filter((person) => person.userPrincipalName);\r\n            this.loading = false;\r\n            if (!this.items.length) {\r\n                this.noData = true;\r\n            }\r\n        }, 500);\r\n    }\r\n}\r\n</script>\r\n\r\n<style lang=\"scss\">\r\n// importing the bootstrap theme from cool select here\r\n.IZ-select * {\r\n    box-sizing: border-box;\r\n}\r\n.IZ-select__input-wrap {\r\n    display: flex;\r\n    align-items: center;\r\n    height: 100%;\r\n}\r\n.IZ-select__input,\r\n.IZ-select__input input {\r\n    height: 100%;\r\n}\r\n.fade-leave-active {\r\n    position: absolute;\r\n}\r\n.fade-enter-active,\r\n.fade-leave,\r\n.fade-leave-to {\r\n    transition: opacity 0.2s;\r\n}\r\n.fade-enter,\r\n.fade-leave-to {\r\n    opacity: 0;\r\n}\r\n.IZ-select {\r\n    position: relative;\r\n    outline: none;\r\n}\r\n.IZ-select .IZ-select__input {\r\n    font-weight: 400;\r\n    font-size: 1rem;\r\n    line-height: 1.5;\r\n}\r\n.IZ-select .IZ-select__input input {\r\n    height: calc(1.5em + 0.75rem);\r\n    padding: 0.375rem 0.75rem;\r\n}\r\n.IZ-select--sm .IZ-select__input {\r\n    border-radius: 0.2rem;\r\n}\r\n.IZ-select--sm .IZ-select__input input {\r\n    height: calc(1.5em + 0.5rem);\r\n    padding: 0.25rem 0.5rem;\r\n    font-size: 0.875rem;\r\n    line-height: 1.5;\r\n}\r\n.IZ-select--lg .IZ-select__input {\r\n    border-radius: 0.3rem;\r\n}\r\n.IZ-select--lg .IZ-select__input input {\r\n    height: calc(1.5em + 1rem);\r\n    padding: 0.5rem 1rem;\r\n    font-size: 1.25rem;\r\n    line-height: 1.5;\r\n}\r\n.IZ-select__input {\r\n    align-items: center;\r\n    display: flex;\r\n    flex: 1 1 auto;\r\n    flex-wrap: wrap;\r\n    width: 100%;\r\n    color: #495057;\r\n    background-color: #fff;\r\n    background-clip: padding-box;\r\n    border: 1px solid #ced4da;\r\n    border-radius: 0.25rem;\r\n    transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\r\n}\r\n.IZ-select__input.IZ-select__input--selection-slot {\r\n    padding-left: 0.75rem;\r\n}\r\n.IZ-select__input.IZ-select__input--selection-slot input {\r\n    padding-left: 10px;\r\n}\r\n.IZ-select__input.IZ-select__input--has-error {\r\n    border: 1px solid #dc3545 !important;\r\n    caret-color: #ff5252 !important;\r\n}\r\n.IZ-select__input.IZ-select__input--has-error input {\r\n    color: #ff5252 !important;\r\n}\r\n.IZ-select__input.IZ-select__input--successful {\r\n    border: 1px solid #28a745 !important;\r\n    caret-color: #28c346 !important;\r\n}\r\n.IZ-select__input.IZ-select__input--focused {\r\n    border-color: #80bdff;\r\n    outline: 0;\r\n    box-shadow: 0 0 0 0.2rem rgba(128, 189, 255, 0.5);\r\n}\r\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--has-error {\r\n    box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25) !important;\r\n}\r\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--successful {\r\n    box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25) !important;\r\n}\r\n.IZ-select__input.IZ-select__input--disabled {\r\n    pointer-events: none;\r\n    background-color: #e9ecef;\r\n    opacity: 1;\r\n}\r\n.IZ-select__input.IZ-select__input--disabled input {\r\n    color: #6c737a !important;\r\n}\r\n.IZ-select__input.IZ-select__input--disabled::-webkit-input-placeholder {\r\n    color: #6c737a !important;\r\n}\r\n.IZ-select__input.IZ-select__input--disabled::-moz-placeholder {\r\n    color: #6c737a !important;\r\n}\r\n.IZ-select__input.IZ-select__input--disabled:-ms-input-placeholder {\r\n    color: #6c737a !important;\r\n}\r\n.IZ-select__input.IZ-select__input--disabled::-ms-input-placeholder {\r\n    color: #6c737a !important;\r\n}\r\n.IZ-select__input.IZ-select__input--disabled::placeholder {\r\n    color: #6c737a !important;\r\n}\r\n.IZ-select__input input {\r\n    font-size: 1rem;\r\n    background-size: 25px 25px;\r\n    background-position: right 10px center;\r\n    background-repeat: no-repeat;\r\n    color: #495057 !important;\r\n    background-color: transparent;\r\n    border-style: none;\r\n    pointer-events: auto;\r\n    flex: 1 1;\r\n    margin-top: 0;\r\n    min-width: 0;\r\n    position: relative;\r\n    line-height: 20px;\r\n    max-width: 100%;\r\n    width: 100%;\r\n}\r\n.IZ-select__input input:focus {\r\n    outline: none;\r\n}\r\n.IZ-select__input input:disabled {\r\n    pointer-events: none;\r\n}\r\n.IZ-select__menu {\r\n    opacity: 0;\r\n    transition: opacity 0.1s;\r\n    position: absolute;\r\n    z-index: 8;\r\n    transform-origin: left top 0;\r\n    background-color: #fff;\r\n    border: 1px solid #ced4da;\r\n    border-radius: 0.25rem;\r\n    box-shadow: 0 2px 11px -2px rgba(0, 0, 0, 0.19);\r\n}\r\n.IZ-select__menu--at-top {\r\n    border-bottom: 0;\r\n    border-bottom-left-radius: 0;\r\n    border-bottom-right-radius: 0;\r\n}\r\n.IZ-select__menu--at-top.IZ-select__menu--disable-search {\r\n    border-bottom: 1px;\r\n    border-bottom-left-radius: 0.25rem;\r\n    border-bottom-right-radius: 0.25rem;\r\n}\r\n.IZ-select__menu--at-bottom {\r\n    border-top: 0;\r\n    border-top-left-radius: 0;\r\n    border-top-right-radius: 0;\r\n}\r\n.IZ-select__menu--at-bottom.IZ-select__menu--disable-search {\r\n    border-top: 1px;\r\n    border-top-left-radius: 0.25rem;\r\n    border-top-right-radius: 0.25rem;\r\n}\r\n.IZ-select__menu .IZ-select__menu-items {\r\n    overflow-y: auto;\r\n    overflow-x: hidden;\r\n}\r\n.IZ-select__menu .IZ-select__no-data {\r\n    margin: 0 10px;\r\n}\r\n.IZ-select__item {\r\n    cursor: pointer;\r\n    padding: 10px 14px;\r\n    transition: 0.3s cubic-bezier(0.25, 0.8, 0.5, 1);\r\n}\r\n.IZ-select__item:hover {\r\n    background-color: #f2f2f2;\r\n}\r\n.IZ-select__item.IZ-select__item--selected {\r\n    color: #1976d2 !important;\r\n}\r\n.IZ-select__error {\r\n    margin-top: 0.55rem;\r\n    font-size: 85%;\r\n    color: #dc3545;\r\n}\r\n.associate {\r\n    display: flex;\r\n    align-items: center;\r\n}\r\n.jobTitle {\r\n    color: grey;\r\n}\r\n.profileImage {\r\n    max-width: 60px;\r\n    margin-right: 10px;\r\n    border: 1px solid #eaecf0;\r\n}\r\n.loading-indicator {\r\n    width: 20px;\r\n    margin-right: 10px;\r\n}\r\n</style>\r\n",".IZ-select * {\n  box-sizing: border-box;\n}\n\n.IZ-select__input-wrap {\n  display: flex;\n  align-items: center;\n  height: 100%;\n}\n\n.IZ-select__input,\n.IZ-select__input input {\n  height: 100%;\n}\n\n.fade-leave-active {\n  position: absolute;\n}\n\n.fade-enter-active,\n.fade-leave,\n.fade-leave-to {\n  transition: opacity 0.2s;\n}\n\n.fade-enter,\n.fade-leave-to {\n  opacity: 0;\n}\n\n.IZ-select {\n  position: relative;\n  outline: none;\n}\n\n.IZ-select .IZ-select__input {\n  font-weight: 400;\n  font-size: 1rem;\n  line-height: 1.5;\n}\n\n.IZ-select .IZ-select__input input {\n  height: calc(1.5em + 0.75rem);\n  padding: 0.375rem 0.75rem;\n}\n\n.IZ-select--sm .IZ-select__input {\n  border-radius: 0.2rem;\n}\n\n.IZ-select--sm .IZ-select__input input {\n  height: calc(1.5em + 0.5rem);\n  padding: 0.25rem 0.5rem;\n  font-size: 0.875rem;\n  line-height: 1.5;\n}\n\n.IZ-select--lg .IZ-select__input {\n  border-radius: 0.3rem;\n}\n\n.IZ-select--lg .IZ-select__input input {\n  height: calc(1.5em + 1rem);\n  padding: 0.5rem 1rem;\n  font-size: 1.25rem;\n  line-height: 1.5;\n}\n\n.IZ-select__input {\n  align-items: center;\n  display: flex;\n  flex: 1 1 auto;\n  flex-wrap: wrap;\n  width: 100%;\n  color: #495057;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid #ced4da;\n  border-radius: 0.25rem;\n  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n\n.IZ-select__input.IZ-select__input--selection-slot {\n  padding-left: 0.75rem;\n}\n\n.IZ-select__input.IZ-select__input--selection-slot input {\n  padding-left: 10px;\n}\n\n.IZ-select__input.IZ-select__input--has-error {\n  border: 1px solid #dc3545 !important;\n  caret-color: #ff5252 !important;\n}\n\n.IZ-select__input.IZ-select__input--has-error input {\n  color: #ff5252 !important;\n}\n\n.IZ-select__input.IZ-select__input--successful {\n  border: 1px solid #28a745 !important;\n  caret-color: #28c346 !important;\n}\n\n.IZ-select__input.IZ-select__input--focused {\n  border-color: #80bdff;\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(128, 189, 255, 0.5);\n}\n\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--has-error {\n  box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25) !important;\n}\n\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--successful {\n  box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25) !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled {\n  pointer-events: none;\n  background-color: #e9ecef;\n  opacity: 1;\n}\n\n.IZ-select__input.IZ-select__input--disabled input {\n  color: #6c737a !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled::-webkit-input-placeholder {\n  color: #6c737a !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled::-moz-placeholder {\n  color: #6c737a !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled:-ms-input-placeholder {\n  color: #6c737a !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled::-ms-input-placeholder {\n  color: #6c737a !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled::placeholder {\n  color: #6c737a !important;\n}\n\n.IZ-select__input input {\n  font-size: 1rem;\n  background-size: 25px 25px;\n  background-position: right 10px center;\n  background-repeat: no-repeat;\n  color: #495057 !important;\n  background-color: transparent;\n  border-style: none;\n  pointer-events: auto;\n  flex: 1 1;\n  margin-top: 0;\n  min-width: 0;\n  position: relative;\n  line-height: 20px;\n  max-width: 100%;\n  width: 100%;\n}\n\n.IZ-select__input input:focus {\n  outline: none;\n}\n\n.IZ-select__input input:disabled {\n  pointer-events: none;\n}\n\n.IZ-select__menu {\n  opacity: 0;\n  transition: opacity 0.1s;\n  position: absolute;\n  z-index: 8;\n  transform-origin: left top 0;\n  background-color: #fff;\n  border: 1px solid #ced4da;\n  border-radius: 0.25rem;\n  box-shadow: 0 2px 11px -2px rgba(0, 0, 0, 0.19);\n}\n\n.IZ-select__menu--at-top {\n  border-bottom: 0;\n  border-bottom-left-radius: 0;\n  border-bottom-right-radius: 0;\n}\n\n.IZ-select__menu--at-top.IZ-select__menu--disable-search {\n  border-bottom: 1px;\n  border-bottom-left-radius: 0.25rem;\n  border-bottom-right-radius: 0.25rem;\n}\n\n.IZ-select__menu--at-bottom {\n  border-top: 0;\n  border-top-left-radius: 0;\n  border-top-right-radius: 0;\n}\n\n.IZ-select__menu--at-bottom.IZ-select__menu--disable-search {\n  border-top: 1px;\n  border-top-left-radius: 0.25rem;\n  border-top-right-radius: 0.25rem;\n}\n\n.IZ-select__menu .IZ-select__menu-items {\n  overflow-y: auto;\n  overflow-x: hidden;\n}\n\n.IZ-select__menu .IZ-select__no-data {\n  margin: 0 10px;\n}\n\n.IZ-select__item {\n  cursor: pointer;\n  padding: 10px 14px;\n  transition: 0.3s cubic-bezier(0.25, 0.8, 0.5, 1);\n}\n\n.IZ-select__item:hover {\n  background-color: #f2f2f2;\n}\n\n.IZ-select__item.IZ-select__item--selected {\n  color: #1976d2 !important;\n}\n\n.IZ-select__error {\n  margin-top: 0.55rem;\n  font-size: 85%;\n  color: #dc3545;\n}\n\n.associate {\n  display: flex;\n  align-items: center;\n}\n\n.jobTitle {\n  color: grey;\n}\n\n.profileImage {\n  max-width: 60px;\n  margin-right: 10px;\n  border: 1px solid #eaecf0;\n}\n\n.loading-indicator {\n  width: 20px;\n  margin-right: 10px;\n}\n\n/*# sourceMappingURL=AssociatePicker.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    createInjector,
    undefined,
    undefined
  );

const formatDate = (value) => {
    if (value) {
        return new Date(value).toLocaleString('en-US', {
            month: 'numeric',
            day: 'numeric',
            year: 'numeric',
        });
    }
};

const truncate = (text, length, clamp) => {
    clamp = clamp || '...';
    var node = document.createElement('div');
    node.innerHTML = text;
    var content = node.textContent;
    return content.length > length ? content.slice(0, length) + clamp : content;
};

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

function unwrapExports (x) {
	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var radio = createCommonjsModule(function (module, exports) {
/*!
 * pretty-checkbox-vue v1.1.9
 * (c) 2017-2018 Hamed Ehtesham
 * Released under the MIT License.
 */
!function(e,t){module.exports=t();}("undefined"!=typeof self?self:commonjsGlobal,function(){return function(e){var t={};function i(s){if(t[s])return t[s].exports;var n=t[s]={i:s,l:!1,exports:{}};return e[s].call(n.exports,n,n.exports,i),n.l=!0,n.exports}return i.m=e,i.c=t,i.d=function(e,t,s){i.o(e,t)||Object.defineProperty(e,t,{configurable:!1,enumerable:!0,get:s});},i.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return i.d(t,"a",t),t},i.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},i.p="",i(i.s=1)}([function(e,t){e.exports=function(e,t,i,s,n,r){var o,a=e=e||{},u=typeof e.default;"object"!==u&&"function"!==u||(o=e,a=e.default);var h,l="function"==typeof a?a.options:a;if(t&&(l.render=t.render,l.staticRenderFns=t.staticRenderFns,l._compiled=!0),i&&(l.functional=!0),n&&(l._scopeId=n),r?(h=function(e){(e=e||this.$vnode&&this.$vnode.ssrContext||this.parent&&this.parent.$vnode&&this.parent.$vnode.ssrContext)||"undefined"==typeof __VUE_SSR_CONTEXT__||(e=__VUE_SSR_CONTEXT__),s&&s.call(this,e),e&&e._registeredComponents&&e._registeredComponents.add(r);},l._ssrRegister=h):s&&(h=s),h){var d=l.functional,c=d?l.render:l.beforeCreate;d?(l._injectStyles=h,l.render=function(e,t){return h.call(t),c(e,t)}):l.beforeCreate=c?[].concat(c,h):[h];}return {esModule:o,exports:a,options:l}};},function(e,t,i){var s=i(0)(i(2),null,!1,null,null,null);s.options.__file="src/PrettyRadio.vue",e.exports=s.exports;},function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0});var s=i(3),n={name:"pretty-radio",input_type:"radio",model:s.model,props:s.props,data:s.data,computed:s.computed,watch:s.watch,mounted:s.mounted,methods:s.methods,render:s.render};t.default=n;},function(e,t,i){var s=i(0)(i(4),i(5),!1,null,null,null);s.options.__file="src/PrettyInput.vue",e.exports=s.exports;},function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.default={name:"pretty-input",model:{prop:"modelValue",event:"change"},props:{type:String,name:String,value:{},modelValue:{},trueValue:{},falseValue:{},checked:{},disabled:{},required:{},indeterminate:{},color:String,offColor:String,hoverColor:String,indeterminateColor:String,toggle:{},hover:{},focus:{}},data:function(){return {m_checked:void 0,default_mode:!1}},computed:{_type:function(){return this.$options.input_type?this.$options.input_type:this.type?this.type:"checkbox"},shouldBeChecked:function(){return void 0!==this.modelValue?"radio"===this._type?this.modelValue===this.value:this.modelValue instanceof Array?this.modelValue.includes(this.value):this._trueValue?this.modelValue===this.trueValue:"string"==typeof this.modelValue||!!this.modelValue:void 0===this.m_checked?this.m_checked="string"==typeof this.checked||!!this.checked:this.m_checked},_disabled:function(){return "string"==typeof this.disabled||!!this.disabled},_required:function(){return "string"==typeof this.required||!!this.required},_indeterminate:function(){return "string"==typeof this.indeterminate||!!this.indeterminate},_trueValue:function(){return "string"==typeof this.trueValue?this.trueValue:!!this.trueValue},_falseValue:function(){return "string"==typeof this.falseValue?this.falseValue:!!this.falseValue},_toggle:function(){return "string"==typeof this.toggle||!!this.toggle},_hover:function(){return "string"==typeof this.hover||!!this.hover},_focus:function(){return "string"==typeof this.focus||!!this.focus},classes:function(){return {pretty:!0,"p-default":this.default_mode,"p-round":"radio"===this._type&&this.default_mode,"p-toggle":this._toggle,"p-has-hover":this._hover,"p-has-focus":this._focus,"p-has-indeterminate":this._indeterminate}},onClasses:function(){var e={state:!0,"p-on":this._toggle};return this.color&&(e["p-"+this.color]=!0),e},offClasses:function(){var e={state:!0,"p-off":!0};return this.offColor&&(e["p-"+this.offColor]=!0),e},hoverClasses:function(){var e={state:!0,"p-is-hover":!0};return this.hoverColor&&(e["p-"+this.hoverColor]=!0),e},indeterminateClasses:function(){var e={state:!0,"p-is-indeterminate":!0};return this.indeterminateColor&&(e["p-"+this.indeterminateColor]=!0),e}},watch:{checked:function(e){this.m_checked=e;},indeterminate:function(e){this.$refs.input.indeterminate=e;}},mounted:function(){this.$vnode.data&&!this.$vnode.data.staticClass&&(this.default_mode=!0),this._indeterminate&&(this.$refs.input.indeterminate=!0),this.$el.setAttribute("p-"+this._type,"");},methods:{updateInput:function(e){if("radio"!==this._type){this.$emit("update:indeterminate",!1);var t=e.target.checked;if(this.m_checked=t,this.modelValue instanceof Array){var i=[].concat(function(e){if(Array.isArray(e)){for(var t=0,i=Array(e.length);t<e.length;t++)i[t]=e[t];return i}return Array.from(e)}(this.modelValue));t?i.push(this.value):i.splice(i.indexOf(this.value),1),this.$emit("change",i);}else this.$emit("change",t?!this._trueValue||this.trueValue:!!this._falseValue&&this.falseValue);}else this.$emit("change",this.value);}}};},function(e,t,i){var s=function(){var e=this.$createElement,t=this._self._c||e;return t("div",{class:this.classes},[t("input",{ref:"input",attrs:{type:this._type,name:this.name,disabled:this._disabled,required:this._required},domProps:{checked:this.shouldBeChecked,value:this.value},on:{change:this.updateInput}}),this._v(" "),t("div",{class:this.onClasses},[this._t("extra"),this._v(" "),t("label",[this._t("default")],2)],2),this._v(" "),this._toggle?t("div",{class:this.offClasses},[this._t("off-extra"),this._v(" "),this._t("off-label")],2):this._e(),this._v(" "),this._hover?t("div",{class:this.hoverClasses},[this._t("hover-extra"),this._v(" "),this._t("hover-label")],2):this._e(),this._v(" "),this._indeterminate?t("div",{class:this.indeterminateClasses},[this._t("indeterminate-extra"),this._v(" "),this._t("indeterminate-label")],2):this._e()])};s._withStripped=!0,e.exports={render:s,staticRenderFns:[]};}])});
});

var PrettyRadio = unwrapExports(radio);
var radio_1 = radio.PrettyRadio;

var check = createCommonjsModule(function (module, exports) {
/*!
 * pretty-checkbox-vue v1.1.9
 * (c) 2017-2018 Hamed Ehtesham
 * Released under the MIT License.
 */
!function(e,t){module.exports=t();}("undefined"!=typeof self?self:commonjsGlobal,function(){return function(e){var t={};function i(s){if(t[s])return t[s].exports;var n=t[s]={i:s,l:!1,exports:{}};return e[s].call(n.exports,n,n.exports,i),n.l=!0,n.exports}return i.m=e,i.c=t,i.d=function(e,t,s){i.o(e,t)||Object.defineProperty(e,t,{configurable:!1,enumerable:!0,get:s});},i.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return i.d(t,"a",t),t},i.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},i.p="",i(i.s=1)}([function(e,t){e.exports=function(e,t,i,s,n,r){var o,a=e=e||{},u=typeof e.default;"object"!==u&&"function"!==u||(o=e,a=e.default);var h,l="function"==typeof a?a.options:a;if(t&&(l.render=t.render,l.staticRenderFns=t.staticRenderFns,l._compiled=!0),i&&(l.functional=!0),n&&(l._scopeId=n),r?(h=function(e){(e=e||this.$vnode&&this.$vnode.ssrContext||this.parent&&this.parent.$vnode&&this.parent.$vnode.ssrContext)||"undefined"==typeof __VUE_SSR_CONTEXT__||(e=__VUE_SSR_CONTEXT__),s&&s.call(this,e),e&&e._registeredComponents&&e._registeredComponents.add(r);},l._ssrRegister=h):s&&(h=s),h){var d=l.functional,c=d?l.render:l.beforeCreate;d?(l._injectStyles=h,l.render=function(e,t){return h.call(t),c(e,t)}):l.beforeCreate=c?[].concat(c,h):[h];}return {esModule:o,exports:a,options:l}};},function(e,t,i){var s=i(0)(i(2),null,!1,null,null,null);s.options.__file="src/PrettyCheckbox.vue",e.exports=s.exports;},function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0});var s=i(3),n={name:"pretty-checkbox",input_type:"checkbox",model:s.model,props:s.props,data:s.data,computed:s.computed,watch:s.watch,mounted:s.mounted,methods:s.methods,render:s.render};t.default=n;},function(e,t,i){var s=i(0)(i(4),i(5),!1,null,null,null);s.options.__file="src/PrettyInput.vue",e.exports=s.exports;},function(e,t,i){Object.defineProperty(t,"__esModule",{value:!0}),t.default={name:"pretty-input",model:{prop:"modelValue",event:"change"},props:{type:String,name:String,value:{},modelValue:{},trueValue:{},falseValue:{},checked:{},disabled:{},required:{},indeterminate:{},color:String,offColor:String,hoverColor:String,indeterminateColor:String,toggle:{},hover:{},focus:{}},data:function(){return {m_checked:void 0,default_mode:!1}},computed:{_type:function(){return this.$options.input_type?this.$options.input_type:this.type?this.type:"checkbox"},shouldBeChecked:function(){return void 0!==this.modelValue?"radio"===this._type?this.modelValue===this.value:this.modelValue instanceof Array?this.modelValue.includes(this.value):this._trueValue?this.modelValue===this.trueValue:"string"==typeof this.modelValue||!!this.modelValue:void 0===this.m_checked?this.m_checked="string"==typeof this.checked||!!this.checked:this.m_checked},_disabled:function(){return "string"==typeof this.disabled||!!this.disabled},_required:function(){return "string"==typeof this.required||!!this.required},_indeterminate:function(){return "string"==typeof this.indeterminate||!!this.indeterminate},_trueValue:function(){return "string"==typeof this.trueValue?this.trueValue:!!this.trueValue},_falseValue:function(){return "string"==typeof this.falseValue?this.falseValue:!!this.falseValue},_toggle:function(){return "string"==typeof this.toggle||!!this.toggle},_hover:function(){return "string"==typeof this.hover||!!this.hover},_focus:function(){return "string"==typeof this.focus||!!this.focus},classes:function(){return {pretty:!0,"p-default":this.default_mode,"p-round":"radio"===this._type&&this.default_mode,"p-toggle":this._toggle,"p-has-hover":this._hover,"p-has-focus":this._focus,"p-has-indeterminate":this._indeterminate}},onClasses:function(){var e={state:!0,"p-on":this._toggle};return this.color&&(e["p-"+this.color]=!0),e},offClasses:function(){var e={state:!0,"p-off":!0};return this.offColor&&(e["p-"+this.offColor]=!0),e},hoverClasses:function(){var e={state:!0,"p-is-hover":!0};return this.hoverColor&&(e["p-"+this.hoverColor]=!0),e},indeterminateClasses:function(){var e={state:!0,"p-is-indeterminate":!0};return this.indeterminateColor&&(e["p-"+this.indeterminateColor]=!0),e}},watch:{checked:function(e){this.m_checked=e;},indeterminate:function(e){this.$refs.input.indeterminate=e;}},mounted:function(){this.$vnode.data&&!this.$vnode.data.staticClass&&(this.default_mode=!0),this._indeterminate&&(this.$refs.input.indeterminate=!0),this.$el.setAttribute("p-"+this._type,"");},methods:{updateInput:function(e){if("radio"!==this._type){this.$emit("update:indeterminate",!1);var t=e.target.checked;if(this.m_checked=t,this.modelValue instanceof Array){var i=[].concat(function(e){if(Array.isArray(e)){for(var t=0,i=Array(e.length);t<e.length;t++)i[t]=e[t];return i}return Array.from(e)}(this.modelValue));t?i.push(this.value):i.splice(i.indexOf(this.value),1),this.$emit("change",i);}else this.$emit("change",t?!this._trueValue||this.trueValue:!!this._falseValue&&this.falseValue);}else this.$emit("change",this.value);}}};},function(e,t,i){var s=function(){var e=this.$createElement,t=this._self._c||e;return t("div",{class:this.classes},[t("input",{ref:"input",attrs:{type:this._type,name:this.name,disabled:this._disabled,required:this._required},domProps:{checked:this.shouldBeChecked,value:this.value},on:{change:this.updateInput}}),this._v(" "),t("div",{class:this.onClasses},[this._t("extra"),this._v(" "),t("label",[this._t("default")],2)],2),this._v(" "),this._toggle?t("div",{class:this.offClasses},[this._t("off-extra"),this._v(" "),this._t("off-label")],2):this._e(),this._v(" "),this._hover?t("div",{class:this.hoverClasses},[this._t("hover-extra"),this._v(" "),this._t("hover-label")],2):this._e(),this._v(" "),this._indeterminate?t("div",{class:this.indeterminateClasses},[this._t("indeterminate-extra"),this._v(" "),this._t("indeterminate-label")],2):this._e()])};s._withStripped=!0,e.exports={render:s,staticRenderFns:[]};}])});
});

var PrettyCheck = unwrapExports(check);
var check_1 = check.PrettyCheck;

// import 'node_modules/vue-cool-select/dist/themes/bootstrap.css';
// import './global.scss';
// Declare install function executed by Vue.use()
function install(Vue) {
    if (install.installed) {
        return;
    }
    install.installed = true;
    // check to see if vue secure plugin is installed and throw an error if not
    // we need sharepointContext to work
    Vue.component('p-check', PrettyCheck);
    Vue.component('p-radio', PrettyRadio);
    Vue.use(CoolSelectPlugin);
    Vue.use(VueToast);
    Vue.component("vue-timepicker", VueTimePicker);
    Vue.component('AssociatePicker', __vue_component__);
}
// Create module definition for Vue.use()
const plugin = {
    install,
};
// Auto-install when vue is found (eg. in browser via <script> tag)
let GlobalVue;
if (typeof window !== 'undefined') {
    GlobalVue = window.Vue;
}
else if (typeof global !== 'undefined') {
    GlobalVue = global.Vue;
}
if (GlobalVue) {
    GlobalVue.use(plugin);
}

export default plugin;
export { __vue_component__ as AssociatePicker, formatDate, truncate };
//# sourceMappingURL=vueUIComponents.esm.js.map
